<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;

class QuadroGeralVinculoRepository{
    protected $entityManager;
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ){
        $this->connection = $entityManager->getConnection();
    }

    public function getQuadroGeralVinculo(array $params): array {
        $sql = <<<SQL
            SELECT /*+ ordered*/
                VM.NRVINCULOM,
                VM.NMVINCULOM,
                TO_CHAR(VM.DTADMISSAOVINC, 'DD/MM/YYYY') DTADMISSAOVINC,
                TO_CHAR(ALTS.VRSALARIO, '999G999G990D00', 'NLS_NUMERIC_CHARACTERS = ,.') VRSALARIO,
                TO_CHAR(ALTS.DTALTESALARIO, 'DD/MM/YYYY') DTALTESALARIO,
                FUNCAO.NMOCUPACAOH NMFUNCAO,
                ESC.NMESCALATRABH,
                TVH.NMTIPOVINCULOH,
                SH.NMSITUFUNCH,
                CARGO.NMOCUPACAOH
            FROM
                GPE_VINCULOM VM
            JOIN GPE_VINCULOH VH ON
                VH.NRVINCULOM = VM.NRVINCULOM AND
                VH.NRORG = VM.NRORG AND
                VH.DTMESCOMPETENC = (
                    SELECT
                        MAX(DTMESCOMPETENC)
                    FROM
                        GPE_VINCULOH VH1
                    WHERE
                        VH1.NRORG = VM.NRORG AND
                        VH1.NRVINCULOM = VM.NRVINCULOM AND
                        VH1.DTMESCOMPETENC <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* SITUAÇÃO FUNCIONAL */
            LEFT JOIN GPE_SITUFUNCH SH ON
                (
                    SH.NRORG = VM.NRORG OR
                    SH.NRORG = :P_NRORG_PADRAO
                ) AND
                SH.NRSITUFUNCM = VH.NRSITUFUNCM AND
                SH.DTEFETIVA = (
                    SELECT
                        MAX(SHH.DTEFETIVA)
                    FROM
                        GPE_SITUFUNCH SHH
                    WHERE
                        SHH.NRORG = SH.NRORG AND
                        SHH.NRSITUFUNCM = SH.NRSITUFUNCM AND
                        DTEFETIVA <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* TIPO DE VÍNCULO */
            LEFT JOIN GPE_TIPOVINCULOH TVH ON
                TVH.NRTIPOVINCULOM = VM.NRTIPOVINCULOM AND
                (
                    TVH.NRORG = VM.NRORG OR
                    TVH.NRORG = :P_NRORG_PADRAO
                ) AND
                TVH.DTMESCOMPETENC = (
                    SELECT
                        MAX(TVHH.DTMESCOMPETENC)
                    FROM
                        GPE_TIPOVINCULOH TVHH
                    WHERE
                        TVHH.NRORG = TVH.NRORG AND
                        TVHH.NRTIPOVINCULOM = TVH.NRTIPOVINCULOM AND
                        TVHH.DTMESCOMPETENC <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* SALÁRIO */
            LEFT JOIN GPE_ALTESALARIO ALTS ON
                VM.NRVINCULOM = ALTS.NRVINCULOM AND
                VM.NRORG = ALTS.NRORG AND
                ALTS.DTALTESALARIO = (
                    SELECT
                        MAX(DTALTESALARIO)
                    FROM
                        GPE_ALTESALARIO
                    WHERE
                        NRORG = ALTS.NRORG AND
                        NRVINCULOM = ALTS.NRVINCULOM AND
                        DTALTESALARIO <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* OCUPAÇÃO */
            LEFT JOIN GPE_OCUPACAOH CARGO ON
                CARGO.NROCUPACAOM = VH.NRCARGO AND
                CARGO.NRORG = VH.NRORG AND
                CARGO.DTMESCOMPETENC = (
                    SELECT
                        MAX(CARGOH.DTMESCOMPETENC)
                    FROM
                        GPE_OCUPACAOH CARGOH
                    WHERE
                        CARGOH.NRORG = CARGO.NRORG AND
                        CARGOH.NROCUPACAOM = CARGO.NROCUPACAOM AND
                        CARGOH.DTMESCOMPETENC <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* FUNÇÃO */
            LEFT JOIN GPE_OCUPACAOH FUNCAO ON
                FUNCAO.NROCUPACAOM = VH.NRFUNCAO AND
                FUNCAO.NRORG = VH.NRORG AND
                FUNCAO.DTMESCOMPETENC = (
                    SELECT
                        MAX(FUNCAOH.DTMESCOMPETENC)
                    FROM
                        GPE_OCUPACAOH FUNCAOH
                    WHERE
                        FUNCAOH.NRORG = FUNCAO.NRORG AND
                        FUNCAOH.NROCUPACAOM = FUNCAO.NROCUPACAOM AND
                        FUNCAOH.DTMESCOMPETENC <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                ) /* ESCALA DE TRABALHO */
            LEFT JOIN GPE_ALTEESCALA ON
                GPE_ALTEESCALA.NRVINCULOM = VM.NRVINCULOM AND
                GPE_ALTEESCALA.NRORG = VM.NRORG AND
                GPE_ALTEESCALA.DTINIESCALA = (
                    SELECT
                        MAX(AE1.DTINIESCALA)
                    FROM
                        GPE_ALTEESCALA AE1
                    WHERE
                        AE1.NRORG = VM.NRORG AND
                        AE1.NRVINCULOM = VM.NRVINCULOM AND
                        AE1.DTINIESCALA <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY') AND
                        (
                            AE1.DTFIMESCALA IS NULL OR
                            AE1.DTFIMESCALA >= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                        )
                )
            LEFT JOIN GPE_ESCALATRABH ESC ON
                ESC.NRESCALATRABM = GPE_ALTEESCALA.NRESCALATRABM AND
                ESC.NRORG = VM.NRORG AND
                ESC.DTMESCOMPETENC = (
                    SELECT
                        MAX(ESCH.DTMESCOMPETENC)
                    FROM
                        GPE_ESCALATRABH ESCH
                    WHERE
                        ESCH.NRORG = ESC.NRORG AND
                        ESCH.NRESCALATRABM = ESC.NRESCALATRABM AND
                        ESCH.DTMESCOMPETENC <= TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                )
            WHERE
                VM.NRORG = :P_NRORG
                AND (
                    VM.DTRESCISAOVINC IS NULL OR
                    VM.DTRESCISAOVINC > TO_DATE(:P_DTFINALAPURACAO, 'DD/MM/YYYY')
                )
                AND (
                    :P_NRESTRUTURAS IS NULL OR
                    ( INSTR( :P_NRESTRUTURAS, ',' || VH.NRESTRUTGEREN || ',') ) > 0
                )

            ORDER BY VM.NMVINCULOM
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $quadroVinculo = $std->fetchAll();

        return $quadroVinculo;
    }
}