<?php
/**
 * Created by PhpStorm.
 * User: felipesantos
 * Date: 04/09/2015
 * Time: 12:43
 */

namespace Service\Hcm;

class CalculoService {

    /* Tipos de movimento */
    const MENSAL = 1;
    const FERIAS = 2;
    const DECIMO_TERCEIRO = 4;
    const RESCISAO = 1;
    const ADIANTAMENTO = 10;
    const PLR = 19;
    const VALE_TRANSPORTE = 17;

    private $entityManager;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function getNumeroTipoMovimento($identificador)
    {
        switch($identificador){
            case '1':
                return self::MENSAL;
                break;
            case '2':
                return self::FERIAS;
                break;
            case '3':
                return self::DECIMO_TERCEIRO;
                break;
            case '4':
                return self::RESCISAO;
                break;
            case '5':
                return self::ADIANTAMENTO;
                break;
            case '6':
                return self::PLR;
                break;
            case '18':
                return self::VALE_TRANSPORTE;
                break;
            default:
                return null;
                break;
        }
    }

    public function getEventoLiquidoMovimento($identificador){
        switch($identificador){
            case '1':
            case '2':
            case '3':
            case '5':
            case '6':
                return 3030;
                break;
            case '18':
                return 480;
                break;
            case '4':
                return 3050;
                break;
            default:
                return null;
                break;
        }
    }

    public function getCalculosByMovimentoAndDtocorrenciaAndNrorg($nrtipomoviment, $dtocorrencia, $nrorg){
        try {
            $query = <<<SQL
SELECT *
  FROM FPA_CALCULOFOLHA
 WHERE NRORG = :P_NRORG
   AND TO_CHAR(DTOCORRENCIA,'DD/MM/YYYY') = :P_DTOCORRENCIA
   AND NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT
   AND NROCORRECAL = 1
   AND NRTPMODALIDCAL = 1
SQL;
            $params = array(
                'P_NRORG' => $nrorg,
                'P_DTOCORRENCIA' => $dtocorrencia,
                'P_NRTIPOMOVIMENT' => $nrtipomoviment
            );

            $calculos = $this->entityManager->getConnection()->fetchAll($query, $params);

            return $calculos;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensByCalculoAndVinculoAndNrorg($nrcalculofolha, $nrvinculom, $nrorg){
        try {
            $query = <<<SQL
SELECT *
  FROM FPA_ITECALCFOLHA
 WHERE NRORG = :P_NRORG
   AND NRVINCULOM = :P_NRVINCULOM
   AND NRCALCULOFOLHA = :P_NRCALCULOFOLHA
   AND NREVENTOM = 3030
SQL;
            $params = array(
                'P_NRORG' => $nrorg,
                'P_NRVINCULOM' => $nrvinculom,
                'P_NRCALCULOFOLHA' => $nrcalculofolha
            );
            $itens = $this->entityManager->getConnection()->fetchAll($query, $params);

            return $itens;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensByMovimentoAndEventoAndDtocorrenciaAndVinculoAndNrorg($nrtipomoviment, $nreventom, $dtocorrencia, $nrvinculom, $nrorg, $dtmescompetenc, $somenteFechado, $idutldtocorrencia, $nrocorrecal=null){
        try {

            $clausulaSomenteFechado = '';
            $ocorrenciaCalculo = '';
            
            if($somenteFechado){
                $clausulaSomenteFechado = " /*Apenas retornará o cálculo mensal do vínculo caso esteja fechado.*/
                                            AND (CAL.NRTIPOMOVIMENT <> 1 OR EXISTS ( 
                                                                                SELECT 1 FROM FPA_ITECALCFOLHA FECHADO_MENSAL
                                                                                WHERE CAL.NRTIPOMOVIMENT = 1 
                                                                                AND FECHADO_MENSAL.NRORG = CAL.NRORG
                                                                                AND FECHADO_MENSAL.NRCALCULOFOLHA = CAL.NRCALCULOFOLHA
                                                                                AND FECHADO_MENSAL.NRVINCULOM = :P_NRVINCULOM
                                                                                AND FECHADO_MENSAL.NREVENTOM = 3035
                                                                              )
                                            )
                                            /*Apenas retornará o cálculo de férias do vínculo caso esteja fechado.*/
                                            AND (CAL.NRTIPOMOVIMENT <> 2 OR EXISTS (
                                                                                SELECT 1 FROM FPA_ITECALCFOLHA FECHADO_FERIAS
                                                                                WHERE CAL.NRTIPOMOVIMENT = 2 
                                                                                AND FECHADO_FERIAS.NRORG = CAL.NRORG
                                                                                AND FECHADO_FERIAS.NRCALCULOFOLHA = CAL.NRCALCULOFOLHA
                                                                                AND FECHADO_FERIAS.NRVINCULOM = :P_NRVINCULOM
                                                                                AND FECHADO_FERIAS.NREVENTOM = 3035
                                                                              )
                                            ) ";
            }
            
            if (!is_null($nrocorrecal)) {
                $ocorrenciaCalculo = " AND CAL.NROCORRECAL IN ($nrocorrecal) ";
            }

            $query = <<<SQL
SELECT ITE.NRITEMCALCFOLHA,
       ITE.NRCALCULOFOLHA,
       ITE.NRVINCULOM,
       ITE.NREVENTOM,
       ITE.NRORG,
       ITE.IDEVENDEMONCALC,
       ITE.VRREFFOLHA,
       ITE.VREVENTOFOLHA,
       ITE.QTOCORPROXPERI,
       ITE.IDREFEVALORCALC,
       ITE.DTINCLUSAO,
       ITE.DTULTATU,
       ITE.NRORGINCLUSAO,
       ITE.CDOPERINCLUSAO,
       ITE.NRORGULTATU,
       ITE.CDOPERULTATU,
       NVL(TO_DATE(:P_DTOCORRENCIA, 'DD/MM/YYYY'), ITE.DTOCORRENCIA) DTOCORRENCIA,
       ITE.VRVELHO,
       ITE.NRLOTELANCEVENTO,
       ITE.DTGERULTCNAB,
       ITE.DSITEMCALCFOLHA
  FROM FPA_ITECALCFOLHA ITE
  JOIN FPA_EVENTOH EVEN
    ON EVEN.NREVENTOM = ITE.NREVENTOM
  JOIN FPA_CALCULOFOLHA CAL
    ON CAL.NRCALCULOFOLHA = ITE.NRCALCULOFOLHA
   AND CAL.NRORG = ITE.NRORG
 WHERE ITE.NRORG = :P_NRORG
   AND ITE.NREVENTOM = :P_NREVENTOM
   AND EVEN.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                FROM FPA_EVENTOH HH
                               WHERE HH.NREVENTOM = EVEN.NREVENTOM
                                 AND (DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC,'DD/MM/YYYY') OR :P_DTMESCOMPETENC IS NULL))
   AND ((:P_IDUTLDTOCORRENCIA = 'S' AND (ITE.DTOCORRENCIA = TO_DATE(:P_DTOCORRENCIA,'DD/MM/YYYY') OR :P_DTOCORRENCIA IS NULL))
        OR NVL(:P_IDUTLDTOCORRENCIA,'N') = 'N')
   AND ITE.NRVINCULOM = :P_NRVINCULOM
   AND ITE.VREVENTOFOLHA > 0
   AND CAL.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT
   AND CAL.NRTPMODALIDCAL = 1
   AND (CAL.DTOCORRENCIA = TO_DATE(:P_DTMESCOMPETENC,'DD/MM/YYYY') OR :P_DTMESCOMPETENC IS NULL)
   $clausulaSomenteFechado
   $ocorrenciaCalculo
SQL;
            $params = array(
                'P_NRORG' => $nrorg,
                'P_NREVENTOM' => $nreventom,
                'P_DTOCORRENCIA' => $dtocorrencia,
                'P_NRVINCULOM' => $nrvinculom,
                'P_NRTIPOMOVIMENT' => $nrtipomoviment,
                'P_DTMESCOMPETENC' => $dtmescompetenc,
                'P_IDUTLDTOCORRENCIA' => $idutldtocorrencia,
            );
            $itens = $this->entityManager->getConnection()->fetchAll($query, $params);
            return $itens;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensByMovimentoAndIncidenciaAndDtocorrenciaAndVinculoAndNrorg($dtmescompetenc, $nrtipomoviment, $nrtipoincide, $dtocorrencia, $nrvinculom, $nrorg, $somenteFechado, $idutldtocorrencia, $nrocorrecal, $idtodospagmescompet, $dtpagamento){
        try {
            
            $clausulaSomenteFechado = '';
            $ocorrenciaCalculo = '';
            $getCalcDtOcorrEqDtPag = '';
            
            if($somenteFechado){
                $clausulaSomenteFechado = " /*Apenas retornará o cálculo mensal do vínculo caso esteja fechado.*/
                                            AND (CAL.NRTIPOMOVIMENT <> 1 OR EXISTS ( 
                                                                                SELECT 1 FROM FPA_ITECALCFOLHA FECHADO_MENSAL
                                                                                WHERE CAL.NRTIPOMOVIMENT = 1 
                                                                                AND FECHADO_MENSAL.NRORG = CAL.NRORG
                                                                                AND FECHADO_MENSAL.NRCALCULOFOLHA = CAL.NRCALCULOFOLHA
                                                                                AND FECHADO_MENSAL.NRVINCULOM = :P_NRVINCULOM
                                                                                AND FECHADO_MENSAL.NREVENTOM = 3035
                                                                              )
                                            )
                                            /*Apenas retornará o cálculo de férias do vínculo caso esteja fechado.*/
                                            AND (CAL.NRTIPOMOVIMENT <> 2 OR EXISTS (
                                                                                SELECT 1 FROM FPA_ITECALCFOLHA FECHADO_FERIAS
                                                                                WHERE CAL.NRTIPOMOVIMENT = 2 
                                                                                AND FECHADO_FERIAS.NRORG = CAL.NRORG
                                                                                AND FECHADO_FERIAS.NRCALCULOFOLHA = CAL.NRCALCULOFOLHA
                                                                                AND FECHADO_FERIAS.NRVINCULOM = :P_NRVINCULOM
                                                                                AND FECHADO_FERIAS.NREVENTOM = 3035
                                                                              )
                                            ) ";
            }
            if(!$dtpagamento){
                $dtpagamento = $dtmescompetenc;
            }
            if($idtodospagmescompet == 'S'){
                $getCalcDtOcorrEqDtPag = " 
                AND ( CAL.DTOCORRENCIA BETWEEN ADD_MONTHS( TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'), -6 ) AND :P_DTMESCOMPETENC OR :P_DTMESCOMPETENC IS NULL ) 
                AND TO_CHAR(TO_DATE(ITE.DTOCORRENCIA), 'MM/YYYY') = TO_CHAR(TO_DATE(:P_DTPAGAMENTO, 'DD/MM/YYYY'), 'MM/YYYY') ";
            }else{
                $getCalcDtOcorrEqDtPag = "
                AND (CAL.DTOCORRENCIA = TO_DATE(:P_DTMESCOMPETENC,'DD/MM/YYYY') OR :P_DTMESCOMPETENC IS NULL)
                ";
            }
            if (!is_null($nrocorrecal)) {
                $ocorrenciaCalculo = " AND CAL.NROCORRECAL IN ($nrocorrecal) ";
            }

            $query = <<<SQL
SELECT ITE.NRITEMCALCFOLHA,
       ITE.NRCALCULOFOLHA,
       ITE.NRVINCULOM,
       ITE.NREVENTOM,
       ITE.NRORG,
       ITE.IDEVENDEMONCALC,
       ITE.VRREFFOLHA,
       /*ITE.VREVENTOFOLHA,*/
       ITE.VREVENTOFOLHA * DECODE(IEV.IDINCIDEVENTO,'+',1,'-',-1,0) VREVENTOFOLHA,
       ITE.QTOCORPROXPERI,
       ITE.IDREFEVALORCALC,
       ITE.DTINCLUSAO,
       ITE.DTULTATU,
       ITE.NRORGINCLUSAO,
       ITE.CDOPERINCLUSAO,
       ITE.NRORGULTATU,
       ITE.CDOPERULTATU,
       ITE.DTOCORRENCIA,
       ITE.VRVELHO,
       ITE.NRLOTELANCEVENTO,
       ITE.DTGERULTCNAB,
       ITE.DSITEMCALCFOLHA
  FROM FPA_ITECALCFOLHA ITE
  JOIN FPA_EVENTOH EVEN
    ON EVEN.NREVENTOM = ITE.NREVENTOM
  JOIN FPA_CALCULOFOLHA CAL
    ON CAL.NRCALCULOFOLHA = ITE.NRCALCULOFOLHA
   AND CAL.NRORG = ITE.NRORG
  JOIN FPA_INCIDEVENTO IEV
    ON (IEV.NRORG = ITE.NRORG OR IEV.NRORG = :P_NRORGPADRAO)
   AND IEV.NREVENTOM = ITE.NREVENTOM
   AND IEV.NRTIPOINCIDE = :P_NRTIPOINCIDE
 WHERE ITE.NRORG = :P_NRORG
   AND EVEN.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                FROM FPA_EVENTOH HH
                               WHERE HH.NREVENTOM = EVEN.NREVENTOM
                                 AND (DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC,'DD/MM/YYYY') OR :P_DTMESCOMPETENC IS NULL))
   AND ((:P_IDUTLDTOCORRENCIA = 'S' AND (ITE.DTOCORRENCIA = TO_DATE(:P_DTOCORRENCIA,'DD/MM/YYYY') OR :P_DTOCORRENCIA IS NULL))
        OR NVL(:P_IDUTLDTOCORRENCIA,'N') = 'N')
   AND ITE.NRVINCULOM = :P_NRVINCULOM
   AND ITE.VREVENTOFOLHA > 0
   AND CAL.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT
   AND CAL.NRTPMODALIDCAL = 1
   $getCalcDtOcorrEqDtPag
   $clausulaSomenteFechado
   $ocorrenciaCalculo
   
SQL;
            $params = array(
                'P_NRORG' => $nrorg,
                'P_NRORGPADRAO' => 0,
                'P_NRTIPOINCIDE' => $nrtipoincide,
                'P_DTOCORRENCIA' => $dtocorrencia,
                'P_NRVINCULOM' => $nrvinculom,
                'P_NRTIPOMOVIMENT' => $nrtipomoviment,
                'P_DTMESCOMPETENC' => $dtmescompetenc,
                'P_IDUTLDTOCORRENCIA' => $idutldtocorrencia,
                'P_DTPAGAMENTO' => $dtpagamento
            );
            
            $itens = $this->entityManager->getConnection()->fetchAll($query, $params);
            
            return $itens;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getItensByEstruturasCalculoItemVinculoEvento($nrorg, $dtmescompetenc, $nrtipomoviment, $nrocorrecal, $dtocorrencia, $nreventom, $nrcpfpessoa, $cdcnpjestrut, $cdfilial, $cdcentcust){
        try {

            if (!is_null($nreventom)) {
                $nreventom = explode(',', $nreventom);
                $nreventom = '_' . implode('_', $nreventom) . '_';
            }

            $query = <<<SQL
SELECT EHL.CDCNPJESTRUT, EML.CDINTESTRUTEXPFIL CDFILIAL, EML.CDINTESTRUTEXP CDCENTCUST, TM.NMTIPOMOVIMENT, CF.DTOCORRENCIA DTMESCOMPETENC, PH.NMPESSOA, PH.NRCPFPESSOA, EH.NREVENTOM, EH.NMEVENTOH, EM.IDTIPOEVENTO, EH.IDUNIDREFEREVEN, EH.VRPERCENTUALEVENTO, IC.VRREFFOLHA, IC.VREVENTOFOLHA, IC.DTOCORRENCIA
  FROM FPA_CALCULOFOLHA CF
  JOIN FPA_ITECALCFOLHA IC ON IC.NRORG = CF.NRORG
                          AND IC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
  JOIN GPE_VINCULOM VM ON VM.NRORG = IC.NRORG
                      AND VM.NRVINCULOM = IC.NRVINCULOM
  JOIN GPE_VINCULOH VH ON VH.NRORG = IC.NRORG
                      AND VH.NRVINCULOM = IC.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRORG = VH.NRORG
                                                  AND H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
  JOIN GPE_PESSOAH PH ON PH.NRORG = VM.NRORG
                     AND PH.NRPESSOA = VM.NRPESSOA
                     AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                WHERE H1.NRORG = PH.NRORG
                                                  AND H1.NRPESSOA = PH.NRPESSOA
                                                  AND H1.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
  JOIN ESTRUTURAM EML ON EML.NRORG = VH.NRORG
                     AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
  JOIN ESTRUTURAH EHL ON EHL.NRORG = EML.NRORG
                     AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                     AND EHL.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                WHERE H1.NRORG = EHL.NRORG
                                                  AND H1.NRESTRUTURAM = EHL.NRESTRUTURAM
                                                  AND H1.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
  JOIN ESTRUTURAM EMG ON EMG.NRORG = VH.NRORG
                     AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
  JOIN FPA_EVENTOM EM ON (EM.NRORG = IC.NRORG OR EM.NRORG = :P_NRORGPADRAO)
                     AND EM.NREVENTOM = IC.NREVENTOM
  JOIN FPA_EVENTOH EH ON (EH.NRORG = IC.NRORG OR EH.NRORG = :P_NRORGPADRAO)
                     AND EH.NREVENTOM = IC.NREVENTOM
                     AND EH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM FPA_EVENTOH H1
                                                WHERE H1.NRORG = EH.NRORG
                                                  AND H1.NREVENTOM = EH.NREVENTOM
                                                  AND H1.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
  JOIN FPA_TIPOMOVIMENT TM ON TM.NRTIPOMOVIMENT = CF.NRTIPOMOVIMENT
 WHERE CF.NRORG = :P_NRORG
   AND CF.DTOCORRENCIA = TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY')
   AND CF.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT
   AND CF.NRTPMODALIDCAL = 1
   AND (CF.NROCORRECAL = :P_NROCORRECAL OR :P_NROCORRECAL IS NULL)
   AND (IC.DTOCORRENCIA = :P_DTOCORRENCIA OR :P_DTOCORRENCIA IS NULL)
   AND (INSTR(:P_NREVENTOM, '_'||IC.NREVENTOM||'_') > 0 OR :P_NREVENTOM IS NULL)
   AND (PH.NRCPFPESSOA = :P_NRCPFPESSOA OR :P_NRCPFPESSOA IS NULL)
   AND (EHL.CDCNPJESTRUT = :P_CDCNPJESTRUT OR :P_CDCNPJESTRUT IS NULL)
   AND (EML.CDINTESTRUTEXPFIL = :P_CDFILIAL OR :P_CDFILIAL IS NULL)
   AND (EMG.CDINTESTRUTEXP = :P_CDCENTCUST OR :P_CDCENTCUST IS NULL)
 ORDER BY EHL.CDCNPJESTRUT, CF.DTOCORRENCIA, PH.NRCPFPESSOA, EH.NREVENTOM
SQL;
            $params = array(
                'P_NRORG' => $nrorg,
                'P_NRORGPADRAO' => 0,
                'P_DTMESCOMPETENC' => $dtmescompetenc,
                'P_NRTIPOMOVIMENT' => $nrtipomoviment,
                'P_NROCORRECAL' => $nrocorrecal,
                'P_DTOCORRENCIA' => $dtocorrencia,
                'P_NREVENTOM' => $nreventom,
                'P_NRCPFPESSOA' => $nrcpfpessoa,
                'P_CDCNPJESTRUT' => $cdcnpjestrut,
                'P_CDFILIAL' => $cdfilial,
                'P_CDCENTCUST' => $cdcentcust,
            );
            $itens = $this->entityManager->getConnection()->fetchAll($query, $params);
            return $itens;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
}