<?php

namespace Tests\IntegrationTests;

use Tests\Util;

class AprovacaoSolicitacaoTest extends HcmServicesIntegrationTestCase {

    /**
     * Caso de Testes 1
     * Operador com perfil de acesso adequado para a fase atual da solicitacao
     */
    public function testAprovacaoSolicitacao() {
        $solicitacaoService = Util::getInstanceManager()->getService('SolicitacaoService');

        $solicitacaoService->aprovaSolicitacao(
            Util::DEFAULT_PK, Util::DEFAULT_PK, 'Aprovado'
        );

        $infoFase = $solicitacaoService->getInfoFase(Util::DEFAULT_PK);

        $nrOrdemSeguinteEsperado = 2;

        $this->assertEquals($nrOrdemSeguinteEsperado, $infoFase['NRORDEM_SEGUINTE'] ?? null);
    }

    public static function createTestData(): void {
        $DEFAULT_PK = Util::DEFAULT_PK;
        $DEFAULT_ORG = Util::DEFAULT_ORG;
        
        $connection = Util::getConnection();
        $connection->setAutoCommit(false);

        $sqls = [
            /* Vinculo que sera associado a solicitacao */

            // Parceiro de negocio
            "Insert into PARCNEGOCIO (NRPARCNEGOCIO,NRORG,CDSEGMER,NMPRINCIPALPARC,NMSECUNDARIPARC,DTNASCIFUNDPARC,NRINSCRICAOPARC,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,CDTIPOPARCPRINCIPAL,CDTIPOINSCRICAO,IDPESSOAFISICA,IDINSTITUICAO,DSDEPARTAMENTO,IDIDIOMA,CDATIVCLI,NRSEQTPATIVCLI,IDPARCFUNDIDO,CDOPERRESPONSAVEL,NRTPCLASSIFICAPARC,DSDIRLOGOMARCA,CDINSCESTA,CDINSCMUNI)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},null,'VINCULO TESTES INTEGRACAO','VINCULO TESTES INTEGRACAO',to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'S',to_date('19/03/2020 15:55:13','DD/MM/RRRR HH24:MI:SS'),to_date('20/03/2020 17:30:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'987654321125','PESSOA','CPF','S','N',null,null,null,null,'N',null,null,null,null,null)",

            // Pessoa
            "Insert into GPE_PESSOA (NRPESSOA,NRORG,NRPARCNEGOCIO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTESOCIAL,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},{$DEFAULT_PK},to_date('19/03/2020 15:55:13','DD/MM/RRRR HH24:MI:SS'),to_date('20/03/2020 17:30:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'987654321125',null,'S')",

            // Historico pessoa
            "Insert into GPE_PESSOAH (NRPESSOAH,NRPESSOA,NRORG,DTMESCOMPETENC,NMPESSOA,DSPRONOMETRAT,DSAPELIDOPESS,DSPRINOMEPESS,DSULTNOMEPESS,DSNOMEMEIOPESS,CDESTACIVIL,NRCONDFISPES,NRANOCHEGAPAIS,NRDOCUESTRANG,IDPOSVISTOPERM,DTPERMAVISTO,IDPESNATURALIZA,DTNATURALIZAPES,NRCPFPESSOA,NRREGCTPSPES,NRCTPSPESSOA,NRSERIECTPSPES,SGUFCTPSPES,DTCTPSPESSOA,NRPISPASEPPES,DTINSCPISPASEP,NRINSCINSSPES,NRINSCISSPES,NRCERTNASCPES,NRCERTCASAPES,DTCASAPESSOA,IDISENTITUELEI,NRTITUELEIPES,NRSECAELEIPES,NRZONAELEIPES,NRCARTHABPES,DTHABCARTPES,DTVALHABCARTPES,DSCATEGHABCART,NRCATMILITARPE,NRCERTRESEPES,DSCATEGCERTRESE,DTCERTRESEPES,CDEXCERTRESEPES,NRCONSELHOREG,NRINSCRCONSREG,DTEXCONSREG,SGUFCONSREG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRRACAPESSOA,IDGRUPSANGUPES,IDFATORRHPES,CDPAIS,SGESTADO,CDMUNICIPIO,DTNASCPESSOA,IDSEXOPESSOA,CDTPBAIXAPAG,NRRGPESSOA,CDEXRGPESSOA,SGUFRGPESSOA,DSLOCALEXRGPES,DTEXRGPESSOA,NRNACIONALID,NRGRAUINSTR,DSCOMPLCERTNASC,NRLIVROCERTNASC,NRFOLHACERTNASC,DSCAMINHOFOTO,IDPOSSUIFILHO,NRIDADEFILHO,DTINIVIGENCIA,DTFIMVIGENCIA,NRLIVROCERTCASA,NRFOLHACERTCASA,SGUFHABCARPES,DSEXPDOCESTR,NRCLASSESTRANG,NRCERTOBITO,DTCHEGADAPAIS,NRSUSPESSOA,NRNITPESSOA,DTADMISSAOPRE,CDRECIBOADMPRE,IDCOTAPCD,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/02/2019 00:00:00','DD/MM/RRRR HH24:MI:SS'),'VINCULO TESTES INTEGRACAO',null,null,'VINCULO','INTEGRACAO','TESTES','S','1',null,null,null,null,null,null,'76276568007',null,null,null,null,null,null,null,null,null,null,null,null,'N','111111111111','0083','026',null,null,null,null,null,'11111111111',null,to_date('25/09/2018 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,null,to_date('18/02/2019 15:34:06','DD/MM/RRRR HH24:MI:SS'),to_date('19/02/2019 18:24:11','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512534784',{$DEFAULT_ORG},'000125241187','2',null,null,'0055','MG','4123',to_date('03/07/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),'M',null,'18087835','PCMG','MG','BELO HORIZONTE',to_date('09/11/2015 00:00:00','DD/MM/RRRR HH24:MI:SS'),'1','7',null,null,null,null,'N',null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,'S')",

            // Vinculo
            "Insert into GPE_VINCULOM (NRVINCULOM,NRPESSOA,NRORG,DTADMISSAOVINC,DTRESCISAOVINC,CDMATRICULA,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRTIPOVINCULOM,NRVINCULOEMPREG,NRTPADMISSAO,NRTPDEMISSAO,DTOPCAOFGTS,DTAPOSENTAFGTS,DTPRIMADMISSAO,NMVINCULOM,NRMOTIVORESC,DSOBSRESCISAO,DTAVISOPREVIO,NRDIASCONTRATOEXP,NRDIASCONTRATOEXPPRO,DTEXAMEMEDICO,DTAVISOTRCT,DSLIVROADMISSAO,IDSEGDESEMPVINC,NRDIASAPURVALES,NRTPAVIPRE,DTENTREGAEPI,DSOBSERVACAORESCISAO,IDVERIFICARESCISAO,IDTPREINTEGRACAO,NRPROCJUD,NRLEIANISTIA,IDPAGTOJUIZO,DTRETORNO,DTEFEITOFINANCEIRO,OBSREINTEGRACAO,DTCANCAVIPRE,NRMOTIVOCANCAP,DSOBSCANCAVIPRE,DTESOCIAL,DTVENCCONTREXPER,NRCLAUSASSECURAT,NRMOTIVOADMISSAO,NRVINCULOMSUBST,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},{$DEFAULT_ORG},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,{$DEFAULT_PK},to_date('24/07/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/07/2023 11:37:34','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512535894',{$DEFAULT_ORG},'102512535894','1','1','2',null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'VINCULO TESTES INTEGRACAO',null,null,null,null,null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,null,'N',null,null,null, EMPTY_CLOB(),null,null,null,null,'S',null,null,null,null,null,null,null,null,null,null,'0','S')",

            // Historico vinculo
            "Insert into GPE_VINCULOH (NRVINCULOH,NRVINCULOM,NRSITUFUNCM,NRCARGO,NRESCALATRABM,NRORG,DTMESCOMPETENC,IDCONTRIBUISIND,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRDEPENDIR,NRDEPENDSFAM,DTBASEFERIAS,IDREMUNERACAO,IDTPPAGAMENTO,NRESTRUTLEGAL,NRESTRUTGEREN,NRTPMODALIDSAL,IDMULTVINC,NRFUNCAO,CDCONTRIBINDIVIDUAL,NRTPMOVTRANSFM,DTFIMCONTRDETERMIN,NRESTRUTSIND,CONFIDENCIAL,NRDIASAPURVALES,NRTURNO,NRTPREGIMEPREV,IDASSOCSINDICATO,CDMATRICULAESOCIAL,NRFAIXA,IDPAGPROPFER13,NRAGENTENOCIVO,IDPARTARTCLT,IDATIVO)
            values ({$DEFAULT_PK},{$DEFAULT_PK},'1','115044','18316',{$DEFAULT_ORG},to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'NUNCA',to_date('24/07/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),to_date('25/07/2023 11:38:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'102512535894',{$DEFAULT_ORG},'102512535894',null,null,to_date('01/01/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'MENSAL',null,null,'1','UNICO',null,null,null,null,'121000025','N',null,null,null,'N',null,null,'N',null,null,'S')",

            /* Operador que aprovara a solicitacao */

            // Parceiro de negocio
            "Insert into PARCNEGOCIO (NRPARCNEGOCIO,NRORG,CDSEGMER,NMPRINCIPALPARC,NMSECUNDARIPARC,DTNASCIFUNDPARC,NRINSCRICAOPARC,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,CDTIPOPARCPRINCIPAL,CDTIPOINSCRICAO,IDPESSOAFISICA,IDINSTITUICAO,DSDEPARTAMENTO,IDIDIOMA,CDATIVCLI,NRSEQTPATIVCLI,IDPARCFUNDIDO,CDOPERRESPONSAVEL,NRTPCLASSIFICAPARC,DSDIRLOGOMARCA,CDINSCESTA,CDINSCMUNI)
            values ({$DEFAULT_PK}-1,{$DEFAULT_ORG},null,'VINCULO TESTES INTEGRACAO 2','VINCULO TESTES INTEGRACAO 2',to_date('01/01/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,'S',to_date('19/03/2020 15:55:13','DD/MM/RRRR HH24:MI:SS'),to_date('20/03/2020 17:30:15','DD/MM/RRRR HH24:MI:SS'),{$DEFAULT_ORG},'987654321125',{$DEFAULT_ORG},'987654321125','PESSOA','CPF','S','N',null,null,null,null,'N',null,null,null,null,null)",

            // Operador vinculo
            "Insert into OPERADOR (CDOPERADOR,CDPAIS,SGESTADO,CDMUNICIPIO,NMOPERADOR,NMACESSO,NMCOMPLOPER,DTNASCIMENTO,DSENDEOPER,NMBAIROPER,NRCEPOPER,NRTELEOPER,CDSENHOPER,DTULTATUOPER,CDCLIENTE,NROPERREDE,CDEMPRESA,CDFUNC,NRRAMALOPER,IDLIGEXTOPER,IDSENHVARDIA,DSEMAILOPER,IDOPERMASTER,IDOPERACESSO,CDSENEMAILOP,IDOPERATIVO,CDSETOR,IDFUNINIOPER,HRINIAGEOPER,HRFIMAGEOPER,CDCARGO,DTULTATUSENH,IDTPOPERADOR,IDSTATUSENHA,DTULTACESOPER,NRCELULAROPER,IDATUOPERADOR,CDBANCOPER,CDAGENOPER,CDCCOROPER,CDOPERESPLIBSEN,NRORG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRPARCNEGOCIO,CDSENHAOPERWEB,NRPERFILSELECIONADO,NRORGSELECIONADA,CDFILIALSELECIONADA,CDPROCHABLANOPE,CDPROCHABAPROPE,CDPROCHABFECOPE,IDCADPRAPROVORE,IDCADPRPROCEORE,IDATIVO,NRORGTRAB,NRESTRUTTRAB,NRORGFILIAL,IDIDIOMA,SGOPERADOR,CDSENHAOPERMD5,DSHASHALTERASENHA,DSEMAILOPER_BKP,DSCRIPTORECSENHA,IDCHEFERECEITAM,USR_NRORDEMSETOR,NROPERREDE_BKP,IDOPERSAAS,DSIMAGEMOPER,NRORGOPER,IDOPERMASTERZMART,IDOPERMASTERCP,CDSENHAOPERSUP,NRORGSUP,DTLIMACESSOSUP)
            values ({$DEFAULT_PK},'0055','MG','4123','VINCULO TESTES INTEGRACAO 2',null,null,to_date('03/07/2000 00:00:00','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,'CgKsZ7rKLYBw',to_date('05/09/2023 09:21:12','DD/MM/RRRR HH24:MI:SS'),null,null,null,'0003',null,'N','N','vinculo.testes-integracao@teknisa.com','N','000000000000000000000000000000',null,'A',null,null,null,null,null,null,null,'A',to_date('06/10/2023 15:26:58','DD/MM/RRRR HH24:MI:SS'),null,'S',null,null,null,null,'20',to_date('18/02/2019 15:34:06','DD/MM/RRRR HH24:MI:SS'),to_date('05/09/2023 09:21:12','DD/MM/RRRR HH24:MI:SS'),'20','102512534784','20','102512535894',{$DEFAULT_PK}-1,'c4ca4238a0b923820dcc509a6f75849b',null,null,null,null,null,null,'N','N','S','20',null,null,null,null,null,null,null,null,'N',null,null,null,null,'20','N','N',null,null,null)",

            // Perfis acesso 1
            "Insert into PERFILACESSO (NRPERFILACESSO,NRORG,NMPERFILACESSO,NRPERFACESSOPAI,NRUSERGROUP,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDPERFILACESSOADM)
            values ({$DEFAULT_PK},{$DEFAULT_ORG},'PERFIL TESTES INTEGRACAO 1',null,null,'S',to_date('09/06/2016 17:11:20','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,null,'N')",

            // Perfis acesso 2
            "Insert into PERFILACESSO (NRPERFILACESSO,NRORG,NMPERFILACESSO,NRPERFACESSOPAI,NRUSERGROUP,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDPERFILACESSOADM)
            values ({$DEFAULT_PK}-1,{$DEFAULT_ORG},'PERFIL TESTES INTEGRACAO 2',null,null,'S',to_date('09/06/2016 17:11:20','DD/MM/RRRR HH24:MI:SS'),null,null,null,null,null,'N')",

            // Associacao perfil 1
            "Insert into PERFACESSPARC (NRPERFACESSPARC,NRPARCNEGOCIO,NRPERFILACESSO,DTVALPERFILPARC,NRORG,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTVALIDADE)
            values ({$DEFAULT_PK},{$DEFAULT_PK}-1,{$DEFAULT_PK},null,{$DEFAULT_ORG},'S',to_date('03/08/2023 17:41:27','DD/MM/RRRR HH24:MI:SS'),null,null,'007654322716','1','1',null)",

            // Associacao perfil 2
            "Insert into PERFACESSPARC (NRPERFACESSPARC,NRPARCNEGOCIO,NRPERFILACESSO,DTVALPERFILPARC,NRORG,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,DTVALIDADE)
            values ({$DEFAULT_PK}-1,{$DEFAULT_PK}-1,{$DEFAULT_PK}-1,null,{$DEFAULT_ORG},'S',to_date('03/08/2023 17:41:27','DD/MM/RRRR HH24:MI:SS'),null,null,'007654322716','1','1',null)",

            /* Parametrizacoes da solicitacao */

            // Modelo de aprovacao de solicitacao
            "Insert into GPE_MODELOAPROVSOLI (NRMODELOAPROVSOLI,NMMODELOAPROVSOLI,IDATIVO,NRORG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU)
            values ({$DEFAULT_PK},'MODELO TESTES INTEGRACAO','S',{$DEFAULT_ORG},to_date('25/10/2021 13:14:44','DD/MM/RRRR HH24:MI:SS'),to_date('28/07/2023 11:18:51','DD/MM/RRRR HH24:MI:SS'),null,'102512535554',null,'007654322716')",

            // Adicionando fase 1 no modelo 1
            "Insert into GPE_FASEAPROVSOLI (NRFASEAPROVSOLI,NRMODELOAPROVSOLI,NMFASEAPROVSOLI,NRORDEM,DSNRPERFILACESSO,IDFASEOBRIGATORIA,IDATIVO,NRORG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU)
            values ({$DEFAULT_PK},{$DEFAULT_PK},'FASE MODELO TESTES 1','1',{$DEFAULT_PK},'S','S',{$DEFAULT_ORG},to_date('25/10/2021 13:16:50','DD/MM/RRRR HH24:MI:SS'),to_date('25/10/2021 13:16:50','DD/MM/RRRR HH24:MI:SS'),null,'102512535554',null,'102512535554')",

            // Adicionando fase 2 no modelo 1
            "Insert into GPE_FASEAPROVSOLI (NRFASEAPROVSOLI,NRMODELOAPROVSOLI,NMFASEAPROVSOLI,NRORDEM,DSNRPERFILACESSO,IDFASEOBRIGATORIA,IDATIVO,NRORG,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU)
            values ({$DEFAULT_PK}-1,{$DEFAULT_PK},'FASE MODELO TESTES 2','2',{$DEFAULT_PK},'S','S',{$DEFAULT_ORG},to_date('25/10/2021 13:16:50','DD/MM/RRRR HH24:MI:SS'),to_date('25/10/2021 13:16:50','DD/MM/RRRR HH24:MI:SS'),null,'102512535554',null,'102512535554')",

            // Associacao modelo tipo de solicitacao
            "Insert into GPE_PERFACESTIPOSOLI (NRORG,NRPERFACESTIPOSOLI,NRTIPOSOLICITACAO,NRNIVELAPROVASOLI,NRPERFACESAPROVPRI,NRPERFACESAPROVSEC,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,NRMODELOAPROVSOLI,DSCONSIDERACAO,IDATIVO,NRTIPOVINCULOM,NRESTRUTLEGAL,NRESTRUTGEREN,NRESTRUTSIND,NROCUPACAOM)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},'18',null,null,null,SYSDATE,to_date('28/08/2023 17:10:09','DD/MM/RRRR HH24:MI:SS'),null,'987654322157',null,'007654322672',{$DEFAULT_PK},'CONSIDERACAO TESTES INTEGRACAO','S',null,null,null,null,null)",

            // Solicitacao
            "Insert into GPE_SOLICITACAO (NRORG,NRSOLICITACAO,NRTIPOSOLICITACAO,NRVINCULOM,DTSOLICITACAO,IDAPROVACAOPRI,DTAPROVACAOPRI,CDOPERAPROVPRI,IDAPROVACAOSEC,DTAPROVACAOSEC,CDOPERAPROVSEC,DSOBSSOLICITACAO,DSOBSAPROVAPRI,DSOBSAPROVASEC,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO,DSPATH,NRMODELOAPROVSOLI)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},'18',{$DEFAULT_PK},to_date('01/09/2023 00:00:00','DD/MM/RRRR HH24:MI:SS'),'P',null,null,'P',null,null,'OBSERVACAO TESTES INTEGRACAO',null,null,to_date('19/09/2023 18:38:42','DD/MM/RRRR HH24:MI:SS'),to_date('19/09/2023 18:38:42','DD/MM/RRRR HH24:MI:SS'),null,'007654322672',null,'007654322672','S',null,{$DEFAULT_PK})",

            // item solicitacao 1
            "Insert into GPE_ITEMSOLICITACAO (NRORG,NRITEMSOLICITACAO,NRSOLICITACAO,DSCHAVEITEMSOLI,DSLABELITEMSOLI,DSVALORITEMSOLI,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK},{$DEFAULT_PK},'QTINIHOR','Hora Inicio','19:22',to_date('19/09/2023 18:38:42','DD/MM/RRRR HH24:MI:SS'),null,null,'007654322672','1','1','S')",

            // item solicitacao 2
            "Insert into GPE_ITEMSOLICITACAO (NRORG,NRITEMSOLICITACAO,NRSOLICITACAO,DSCHAVEITEMSOLI,DSLABELITEMSOLI,DSVALORITEMSOLI,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-1,{$DEFAULT_PK},'DTAPROVAHE','Data da Realização das Horas Extras','01/09/2023',to_date('19/09/2023 18:38:42','DD/MM/RRRR HH24:MI:SS'),null,null,'007654322672','1','1','S')",

            // item solicitacao 3
            "Insert into GPE_ITEMSOLICITACAO (NRORG,NRITEMSOLICITACAO,NRSOLICITACAO,DSCHAVEITEMSOLI,DSLABELITEMSOLI,DSVALORITEMSOLI,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU,IDATIVO)
            values ({$DEFAULT_ORG},{$DEFAULT_PK}-2,{$DEFAULT_PK},'QTFIMHOR','Hora Fim','21:02',to_date('19/09/2023 18:38:42','DD/MM/RRRR HH24:MI:SS'),null,null,'007654322672','1','1','S')",
        ];

        foreach ($sqls as $sql) {
            $connection->executeStatement($sql);
        }

        $connection->commit();
    }

    public static function destroyTestData(): void {
        $DEFAULT_PK = Util::DEFAULT_PK;
        $DEFAULT_ORG = Util::DEFAULT_ORG;

        $connection = Util::getConnection();
        $connection->setAutoCommit(false);

        $sqls = [
            "Delete From GPE_ITEMSOLICITACAO Where NRORG = {$DEFAULT_ORG} And NRSOLICITACAO = {$DEFAULT_PK}",
            "Delete From GPE_FASETRAMSOLI Where NRORG = {$DEFAULT_ORG} And NRSOLICITACAO = {$DEFAULT_PK}",
            "Delete From GPE_SOLICITACAO Where NRORG = {$DEFAULT_ORG} And NRSOLICITACAO = {$DEFAULT_PK}",
            "Delete From GPE_FASEAPROVSOLI Where NRORG = {$DEFAULT_ORG} And NRMODELOAPROVSOLI = {$DEFAULT_PK}",
            "Delete From GPE_PERFACESTIPOSOLI Where NRORG = {$DEFAULT_ORG} And NRPERFACESTIPOSOLI = {$DEFAULT_PK}",
            "Delete From PERFACESSPARC Where NRORG = {$DEFAULT_ORG} And NRPARCNEGOCIO = {$DEFAULT_PK}-1",
            "Delete From PERFILACESSO Where NRORG = {$DEFAULT_ORG} And NRPERFILACESSO in ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
            "Delete From GPE_MODELOAPROVSOLI Where NRORG = {$DEFAULT_ORG} And NRMODELOAPROVSOLI = {$DEFAULT_PK}",
            "Delete From OPERADOR Where NRORG = {$DEFAULT_ORG} And NRPARCNEGOCIO = {$DEFAULT_PK}-1",
            "Delete From PTO_PROGOCORRENCIA Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From PTO_ALTEBANCOHORAS Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From PTO_PROGOCORRENCIA Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_ALTEESCALA Where NRORG = {$DEFAULT_ORG} And NRALTEESCALA = {$DEFAULT_PK}",
            "Delete From GPE_VINCULOH Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_VINCULOM Where NRORG = {$DEFAULT_ORG} And NRVINCULOM = {$DEFAULT_PK}",
            "Delete From GPE_PESSOAH Where NRORG = {$DEFAULT_ORG} And NRPESSOA = {$DEFAULT_PK}",
            "Delete From GPE_PESSOA Where NRORG = {$DEFAULT_ORG} And NRPESSOA = {$DEFAULT_PK}",
            "Delete From PARCNEGOCIO Where NRORG = {$DEFAULT_ORG} And NRPARCNEGOCIO in ({$DEFAULT_PK},{$DEFAULT_PK}-1)",
        ];

        foreach ($sqls as $sql) {
            $connection->executeStatement($sql);
        }

        $connection->commit();
    }
}
